@@ -75,7 +75,7 @@ class Namecheap(_defaults_.Defaults):
 			info = response["domains"][domain]
 			exists = True
 		except: exists = False
-		return r3sponse.success_response(f"Successfully checked the ownership for domain [{domain}] from namecheap user [{self.username}].", {"exists":exists})
+		return r3sponse.success(f"Successfully checked the ownership for domain [{domain}] from namecheap user [{self.username}].", {"exists":exists})
 
 		#
 	def get_domains(self):
@@ -85,7 +85,7 @@ class Namecheap(_defaults_.Defaults):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to retrieve the domains of namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to retrieve the domains of namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		domains = {}
@@ -101,7 +101,7 @@ class Namecheap(_defaults_.Defaults):
 			else: raise ValueError(f"Unkown domain type: {domain}.")
 
 		# handlers.
-		return r3sponse.success_response(f"Successfully retrieved the domains of namecheap user [{self.username}].", {
+		return r3sponse.success(f"Successfully retrieved the domains of namecheap user [{self.username}].", {
 			"domains":domains,
 		})
 
@@ -115,23 +115,23 @@ class Namecheap(_defaults_.Defaults):
 		response = self.check_domain(domain)
 		if response.error != None: return response
 		elif not response["exists"]:
-			return r3sponse.error_response(f"Namecheap user [{self.username}] does not own domain [{domain}].")
+			return r3sponse.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
 
 		# api request get info.
 		response = self.__request__("namecheap.domains.getInfo", {"DomainName":domain})
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			info = response["api_response"]["command_response"]["domain_get_info_result"]
 		except KeyError:
-			return r3sponse.error_response(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}].")
 
 		# handlers.
-		return r3sponse.success_response(f"Successfully retrieved the domain info of namecheap user [{self.username}].", {
+		return r3sponse.success(f"Successfully retrieved the domain info of namecheap user [{self.username}].", {
 			"info":info,
 		})
 
@@ -145,7 +145,7 @@ class Namecheap(_defaults_.Defaults):
 		response = self.check_domain(domain)
 		if response.error != None: return response
 		elif not response["exists"]:
-			return r3sponse.error_response(f"Namecheap user [{self.username}] does not own domain [{domain}].")
+			return r3sponse.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
 
 		# api request.
 		response = self.get_sld_and_tld(domain)
@@ -155,13 +155,13 @@ class Namecheap(_defaults_.Defaults):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["domain_dnsget_hosts_result"]
 		except KeyError:
-			return r3sponse.error_response(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}].")
 
 		# iterate data.
 		records = {}
@@ -194,7 +194,7 @@ class Namecheap(_defaults_.Defaults):
 				records[tag] = serialized
 
 		# handlers.
-		return r3sponse.success_response(f"Successfully retrieved the dns info of namecheap user [{self.username}].", {
+		return r3sponse.success(f"Successfully retrieved the dns info of namecheap user [{self.username}].", {
 			"records":records,
 		})
 
@@ -232,7 +232,7 @@ class Namecheap(_defaults_.Defaults):
 
 		# handlers.
 		exists = tag in list(records.keys())
-		return r3sponse.success_response(f"Successfully checked dns record [{tag}] of namecheap user [{self.username}].", {
+		return r3sponse.success(f"Successfully checked dns record [{tag}] of namecheap user [{self.username}].", {
 			"exists":exists,
 			"tag":tag,
 		})
@@ -263,7 +263,7 @@ class Namecheap(_defaults_.Defaults):
 		response = self.check_domain(domain)
 		if response.error != None: return response
 		elif not response["exists"]:
-			return r3sponse.error_response(f"Namecheap user [{self.username}] does not own domain [{domain}].")
+			return r3sponse.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
 
 		# sld & tld.
 		response = self.get_sld_and_tld(domain)
@@ -285,13 +285,13 @@ class Namecheap(_defaults_.Defaults):
 				except KeyError:
 					data[f"TTL{c}"] = 1800
 			except KeyError:
-				return r3sponse.error_response(f"Invalid usage, each record dictionary must have the following keys: [host, type, value].")
+				return r3sponse.error(f"Invalid usage, each record dictionary must have the following keys: [host, type, value].")
 			c += 1
 		response = self.__request__("namecheap.domains.dns.setHosts", data)
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
@@ -301,9 +301,9 @@ class Namecheap(_defaults_.Defaults):
 
 		# handlers.
 		if success:
-			return r3sponse.success_response(f"Successfully set dns records for domain [{domain}] from namecheap user [{self.username}].")
+			return r3sponse.success(f"Successfully set dns records for domain [{domain}] from namecheap user [{self.username}].")
 		else:
-			return r3sponse.error_response(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}].")
 
 		#
 	def add_dns(self,
@@ -341,7 +341,7 @@ class Namecheap(_defaults_.Defaults):
 		# handle exact duplicate.
 		elif response["exists"]:
 			tag = response["tag"]
-			return r3sponse.error_response(f"DNS record [{tag}] from namecheap domain [{domain}] already exists.")
+			return r3sponse.error(f"DNS record [{tag}] from namecheap domain [{domain}] already exists.")
 
 		# add new.
 		else:
@@ -361,7 +361,7 @@ class Namecheap(_defaults_.Defaults):
 			if response.error != None: return response
 
 			# success.
-			return r3sponse.success_response(f"Successfully added dns record [{tag}] to namecheap domain [{domain}].", {"tag":tag})
+			return r3sponse.success(f"Successfully added dns record [{tag}] to namecheap domain [{domain}].", {"tag":tag})
 
 		#
 	def tag_dns(self,
@@ -373,7 +373,7 @@ class Namecheap(_defaults_.Defaults):
 		value=None,
 	):
 		tag = f"{type}|{host}|{value}"
-		return r3sponse.success_response(f"Successfully taggeed dns record [{tag}].", {"tag":tag})
+		return r3sponse.success(f"Successfully taggeed dns record [{tag}].", {"tag":tag})
 	def get_sld_and_tld(self, domain=None):
 
 		# set default domain.
@@ -394,7 +394,7 @@ class Namecheap(_defaults_.Defaults):
 			c += 1
 
 		# handlers.
-		return r3sponse.success_response(f"Successfully retrieded the SLD & TLD of domain [{domain}].", {
+		return r3sponse.success(f"Successfully retrieded the SLD & TLD of domain [{domain}].", {
 			"tld":tld,
 			"sld":sld,
 		})
@@ -407,13 +407,13 @@ class Namecheap(_defaults_.Defaults):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to retrieve the tls list from namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to retrieve the tls list from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["ssllist_result"]
 		except KeyError:
-			return r3sponse.error_response(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
 
 		# iterate data.
 		tls = {}
@@ -427,7 +427,7 @@ class Namecheap(_defaults_.Defaults):
 				tls[_data_["certificate_id"]] = _data_
 
 		# handlers.
-		return r3sponse.success_response(f"Successfully retrieved the tls list for namecheap user [{self.username}].", {
+		return r3sponse.success(f"Successfully retrieved the tls list for namecheap user [{self.username}].", {
 			"tls":tls,
 			"certificates":len(tls),
 		})
@@ -448,17 +448,17 @@ class Namecheap(_defaults_.Defaults):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to create tls certificate from namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to create tls certificate from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["sslcreate_result"]
 		except KeyError:
-			return r3sponse.error_response(f"Failed to create a tls certificate for namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to create a tls certificate for namecheap user [{self.username}].")
 
 		# handlers.
 		if data["is_success"]:
-			return r3sponse.success_response(f"Successfully created a tls certificate for namecheap user [{self.username}].", {
+			return r3sponse.success(f"Successfully created a tls certificate for namecheap user [{self.username}].", {
 				"certificate_id":data["sslcertificate"]["certificate_id"],
 				"order_id":data["order_id"],
 				"transaction_id":data["transaction_id"],
@@ -468,7 +468,7 @@ class Namecheap(_defaults_.Defaults):
 				"years":data["sslcertificate"]["years"],
 			})
 		else:
-			return r3sponse.error_response(f"Failed to create a tls certificate for namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to create a tls certificate for namecheap user [{self.username}].")
 
 		#
 	def activate_tls(self,
@@ -479,7 +479,7 @@ class Namecheap(_defaults_.Defaults):
 		# check csr.
 		csr = f"{self.root}/.secrets/tls/server.csr"
 		if not os.path.exists(csr):
-			return r3sponse.error_response(f"There is no tls certificate present.")
+			return r3sponse.error(f"There is no tls certificate present.")
 		csr = utils.__load_file__(csr)
 
 		# api request.
@@ -492,17 +492,17 @@ class Namecheap(_defaults_.Defaults):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error_response(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}], error: {error}")
+			return r3sponse.error(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["sslactivate_result"]
 		except KeyError:
-			return r3sponse.error_response(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
 
 		# handlers.
 		if not data["is_success"]:
-			return r3sponse.error_response(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}].")
+			return r3sponse.error(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}].")
 
 		# add dns validation record. 
 		dns_validation = data["dnsdcvalidation"]["dns"]
@@ -520,7 +520,7 @@ class Namecheap(_defaults_.Defaults):
 		if response.error != None and "] already exists." not in response.error: return response
 		
 		# handlers.
-		return r3sponse.success_response(f"Successfully activated tls certificate [{certificate_id}] from namecheap user [{self.username}].")
+		return r3sponse.success(f"Successfully activated tls certificate [{certificate_id}] from namecheap user [{self.username}].")
 
 		#
 	# system functions.
